import tsp
import random
import time


def randomDist(n, symmetric=True):
    '''Erzeugt eine zufällige (un)symmetrische 
    Distanztabelle für n Städte'''
    M = []
    for i in range(0, n):
        M.append([])
        for j in range(0, n):
            if i == j:
                M[i].append(0)
            elif j > i:
                M[i].append(random.randint(1,n))
            elif symmetric == True:
                M[i].append(random.randint(1,n))
            else:
                M[i].append(M[j][i])
    return M


def benchmark(n, filename):
    '''Führt eine TSP-Laufzeitmessung mit n Städten durch,
    zeigt die Resultate an und schreibt sie in eine 
    CSV-Datei'''
    
    fd = open(filename, 'w')
    sep = '\t' # csv-separator
    header = 'Anzahl Staedte{0}Dauer in Sekunden\n'.format(sep)
    fd.write(header)

    for i in range(2, n+1):
        D = randomDist(i)
        t1 = time.time()
        tsp.bruteForce(D) 
        t2 = time.time()
        dauer = t2 - t1
        print('{0} Städte -> {1:0.4f} Sekunden'.format(i, dauer))
        fd.write('{0}{1}{2:0.4f}\n'.format(i, sep, dauer))

    fd.close()


benchmark(12, 'tsp-benchmark.csv')    

